pub fn open_database(path: &Path) -> Result<Connection, MemoryError>Expand description
Open or create a SQLite database at path, configure pragmas, and run migrations.
pub fn open_database(path: &Path) -> Result<Connection, MemoryError>Open or create a SQLite database at path, configure pragmas, and run migrations.