pub fn open_database_connection(
path: &Path,
pool: &PoolConfig,
limits: &MemoryLimits,
) -> Result<Connection, MemoryError>Expand description
Open a SQLite connection with pragmas applied but without running migrations.
pub fn open_database_connection(
path: &Path,
pool: &PoolConfig,
limits: &MemoryLimits,
) -> Result<Connection, MemoryError>Open a SQLite connection with pragmas applied but without running migrations.