append_journal_entry

Function append_journal_entry 

pub fn append_journal_entry(
    conn: &Connection,
    home_device_id: &str,
    store_id: &str,
    operation_kind: &str,
    payload: &[u8],
) -> Result<i64, MemoryError>
Append a journal entry within an active transaction.

The caller is responsible for opening the transaction and committing the semantic mutation together. This function only appends the journal row and returns the assigned journal_id.