pub fn next_expected_sequence(
conn: &Connection,
home_device_id: &str,
store_id: &str,
) -> Result<i64, MemoryError>Expand description
Get the next expected sequence number for a device/store pair.
pub fn next_expected_sequence(
conn: &Connection,
home_device_id: &str,
store_id: &str,
) -> Result<i64, MemoryError>Get the next expected sequence number for a device/store pair.