Module quantize_governed

Module quantize_governed 

Governed compression pipeline integration for semantic-memory.

This module evaluates quant-governor policy and produces an artifact only when the selected runtime codec has a real encoder. It never relabels raw bytes as a compressed representation.

Re-exports

pub use governed::encode_governed;
pub use governed::encode_governed_default;
pub use governed::GovernedEncodeResult;

Modules

governed
Stub module when turbo-quant-codec is not enabled.