pub enum StateResolutionMode {
Current,
HistoricalAt(String),
Transition {
from: String,
to: String,
},
Trajectory {
points: Vec<String>,
},
}Expand description
The resolution request, kept separate from the compatible StateView wire enum.
Variants
Implementations
Sourceimpl StateResolutionMode
impl StateResolutionMode
pub fn historical_at(as_of: impl Into<String>) -> Self
pub fn transition(from: impl Into<String>, to: impl Into<String>) -> Self
pub fn trajectory(points: Vec<String>) -> Self
Sourcepub fn state_view(&self) -> StateView
pub fn state_view(&self) -> StateView
Map a resolution request to the existing authoritative fact view.