pub struct ProjectionImportLogEntry {Show 30 fields
pub batch_id: String,
pub source_envelope_id: String,
pub schema_version: String,
pub export_schema_version: Option<String>,
pub content_digest: String,
pub source_authority: String,
pub scope_namespace: String,
pub scope_domain: Option<String>,
pub scope_workspace_id: Option<String>,
pub scope_repo_id: Option<String>,
pub record_count: usize,
pub claim_count: usize,
pub relation_count: usize,
pub episode_count: usize,
pub alias_count: usize,
pub evidence_count: usize,
pub status: String,
pub source_exported_at: Option<String>,
pub transformed_at: Option<String>,
pub imported_at: String,
pub source_run_id: Option<String>,
pub comparability_snapshot_version: Option<String>,
pub direct_write: bool,
pub failure_reason: Option<String>,
pub evidence_bundle_id: Option<String>,
pub evidence_bundle_json: Option<Value>,
pub episode_bundle_id: Option<String>,
pub episode_bundle_json: Option<Value>,
pub execution_context_json: Option<Value>,
pub kernel_payload_json: Option<Value>,
}Expand description
Public view of a V11 projection import log entry.
Fields
batch_id: Stringsource_envelope_id: Stringschema_version: StringImport-side batch schema version recorded at the memory boundary.
export_schema_version: Option<String>Source export schema version preserved as provenance when provided.
content_digest: Stringscope_namespace: Stringscope_domain: Option<String>scope_workspace_id: Option<String>scope_repo_id: Option<String>record_count: usizeclaim_count: usizerelation_count: usizeepisode_count: usizealias_count: usizeevidence_count: usizestatus: Stringsource_exported_at: Option<String>transformed_at: Option<String>imported_at: Stringsource_run_id: Option<String>comparability_snapshot_version: Option<String>direct_write: boolfailure_reason: Option<String>evidence_bundle_id: Option<String>evidence_bundle_json: Option<Value>episode_bundle_id: Option<String>episode_bundle_json: Option<Value>execution_context_json: Option<Value>kernel_payload_json: Option<Value>Implementations
Sourceimpl ProjectionImportLogEntry
impl ProjectionImportLogEntry
pub fn scope_key(&self) -> ScopeKey
pub fn rebuildable_kernel_batch_v3( &self, ) -> Result<Option<ProjectionImportBatchV3>, MemoryError>