pub struct MemoryTransitionCandidateV1 {
pub schema_version: String,
pub candidate_id: String,
pub source_artifacts: Vec<SourceArtifactV1>,
pub required_source_spans: Vec<SourceSpanRefV1>,
pub assertions: Vec<AssertionDraftV1>,
pub operation: TransitionOperation,
pub preserved_active_fact_ids: Vec<String>,
}Expand description
Candidate proposed by extraction or an operator before canonical admission.
Fields
schema_version: Stringcandidate_id: Stringsource_artifacts: Vec<SourceArtifactV1>required_source_spans: Vec<SourceSpanRefV1>assertions: Vec<AssertionDraftV1>operation: TransitionOperationpreserved_active_fact_ids: Vec<String>Current assertions in affected namespaces that the proposal explicitly retains.
Implementations
Sourceimpl MemoryTransitionCandidateV1
impl MemoryTransitionCandidateV1
pub fn new( candidate_id: impl Into<String>, source_artifacts: Vec<SourceArtifactV1>, required_source_spans: Vec<SourceSpanRefV1>, assertions: Vec<AssertionDraftV1>, operation: TransitionOperation, preserved_active_fact_ids: Vec<String>, ) -> Result<Self, String>
pub fn validate(&self) -> Result<(), String>