pub struct DerivedCandidateReceiptV1 {
pub candidate_backend: String,
pub codec_family: Option<String>,
pub generation_id: Option<String>,
pub embedding_snapshot_digest: Option<String>,
pub pool_manifest_digest: Option<String>,
pub exact_rerank: bool,
pub approximate: bool,
pub fallback: Option<String>,
pub raw_candidate_count: usize,
pub post_filter_count: usize,
pub final_result_count: usize,
}Expand description
Structured search receipt for derived candidate generation followed by exact f32 rerank.
Fields
candidate_backend: Stringcodec_family: Option<String>generation_id: Option<String>embedding_snapshot_digest: Option<String>pool_manifest_digest: Option<String>exact_rerank: boolapproximate: boolfallback: Option<String>raw_candidate_count: usizepost_filter_count: usizefinal_result_count: usizeTrait Implementations
Sourceimpl Clone for DerivedCandidateReceiptV1
impl Clone for DerivedCandidateReceiptV1
Sourcefn clone(&self) -> DerivedCandidateReceiptV1
fn clone(&self) -> DerivedCandidateReceiptV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DerivedCandidateReceiptV1
impl Debug for DerivedCandidateReceiptV1
Sourceimpl<'de> Deserialize<'de> for DerivedCandidateReceiptV1
impl<'de> Deserialize<'de> for DerivedCandidateReceiptV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DerivedCandidateReceiptV1
Sourceimpl PartialEq for DerivedCandidateReceiptV1
impl PartialEq for DerivedCandidateReceiptV1
Sourcefn eq(&self, other: &DerivedCandidateReceiptV1) -> bool
fn eq(&self, other: &DerivedCandidateReceiptV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DerivedCandidateReceiptV1