pub enum DerivedVectorBackendPolicy {
Disabled,
TurboQuantCandidateOnly,
FibQuantCandidateOnly,
PerDimCandidateOnly,
}Expand description
Candidate backend policy for rebuildable derived vector artifacts.
Variants
Disabled
Use authoritative raw f32 embeddings for vector candidate generation.
TurboQuantCandidateOnly
Use TurboQuant only to generate candidates, then exact rerank by default.
FibQuantCandidateOnly
Use FibQuant only to generate candidates, then exact rerank by default.
PerDimCandidateOnly
Use PerDimScorer only to generate candidates, then exact rerank by default.